Package org.apache.calcite.sql.fun
-
Class Summary Class Description SqlItemOperator The item operator[ ... ], used to access a given element of an array, map or struct.SqlJsonQueryFunction TheJSON_QUERYfunction.
| Class | Description |
|---|---|
| SqlItemOperator |
The item operator
[ ... ], used to access a given element of an array, map or struct. |
| SqlJsonQueryFunction |
The
JSON_QUERY function. |