Uses of Interface
org.apache.flink.sql.parser.ExtendedSqlNode
-
-
Uses of ExtendedSqlNode in org.apache.flink.sql.parser.ddl
Classes in org.apache.flink.sql.parser.ddl that implement ExtendedSqlNode Modifier and Type Class Description classSqlReplaceTableAsSqlNodeto describe the [CREATE OR] REPLACE TABLE AS (RTAS) syntax. -
Uses of ExtendedSqlNode in org.apache.flink.sql.parser.ddl.connection
Classes in org.apache.flink.sql.parser.ddl.connection that implement ExtendedSqlNode Modifier and Type Class Description classSqlCreateConnectionSqlNodeto describe the CREATE CONNECTION syntax. -
Uses of ExtendedSqlNode in org.apache.flink.sql.parser.ddl.materializedtable
Classes in org.apache.flink.sql.parser.ddl.materializedtable that implement ExtendedSqlNode Modifier and Type Class Description classSqlAlterMaterializedTableSchemaAbstract class to describe statements which are used to alter schema for materialized tables.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableAddSchemaExample: DDL like the below for adding column(s)/constraint/watermark.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropColumnSqlNode to describe ALTER MATERIALIZED TABLE materialized_table_name DROP column clause.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropConstraintALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropPrimaryKeyALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropSchemaAbstract class to describe statements which are used to drop schema components while altering schema of materialized tables.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropWatermarkALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableModifySchemaExample: DDL like the below for modifying column(s)/constraint/watermark.classSqlCreateMaterializedTableCREATE MATERIALIZED TABLE DDL sql call.classSqlCreateOrAlterMaterializedTableCREATE [OR ALTER] MATERIALIZED TABLE DDL sql call. -
Uses of ExtendedSqlNode in org.apache.flink.sql.parser.ddl.model
Classes in org.apache.flink.sql.parser.ddl.model that implement ExtendedSqlNode Modifier and Type Class Description classSqlCreateModelSqlNodeto describe the CREATE MODEL syntax.classSqlCreateModelAsSqlNodeto describe the CREATE MODEL AS syntax. -
Uses of ExtendedSqlNode in org.apache.flink.sql.parser.ddl.table
Classes in org.apache.flink.sql.parser.ddl.table that implement ExtendedSqlNode Modifier and Type Class Description classSqlAlterTableAddSqlNode to describe ALTER TABLE [IF EXISTS] table_name ADD column/constraint/watermark clause.classSqlAlterTableDropSqlNode to describe ALTER TABLE [IF EXISTS ]table_name DROP column/constraint/watermark clause.static classSqlAlterTableDrop.SqlAlterTableDropColumnSqlNode to describe ALTER TABLE [IF EXISTS ]table_name DROP column clause.static classSqlAlterTableDrop.SqlAlterTableDropConstraintALTER TABLE [IF EXISTS ][catalog_name.]static classSqlAlterTableDrop.SqlAlterTableDropPrimaryKeyALTER TABLE [IF EXISTS ][catalog_name.]static classSqlAlterTableDrop.SqlAlterTableDropWatermarkALTER TABLE [IF EXISTS ][catalog_name.]classSqlAlterTableModifySqlNode to describe ALTER TABLE [IF EXISTS] table_name MODIFY column/constraint/watermark clause.classSqlAlterTableSchemaAbstract class to describe statements which are used to alter table schema.classSqlCreateTableCREATE TABLE DDL sql call.classSqlCreateTableAsSqlNodeto describe the CREATE TABLE AS syntax.classSqlCreateTableLikeSqlNodeto describe the CREATE TABLE LIKE syntax.classSqlTableLikeALIKEclause in aCREATE TABLEstatement.
-