Package org.apache.flink.sql.parser.ddl
Class SqlAlterModel
- java.lang.Object
-
- org.apache.calcite.sql.SqlNode
-
- org.apache.calcite.sql.SqlCall
-
- org.apache.flink.sql.parser.ddl.SqlAlterModel
-
- All Implemented Interfaces:
Cloneable
- Direct Known Subclasses:
SqlAlterModelRename,SqlAlterModelReset,SqlAlterModelSet
public abstract class SqlAlterModel extends org.apache.calcite.sql.SqlCallAbstract class to describe statements like ALTER MODEL [IF EXISTS] [[catalogName.] dataBasesName.]modelName ...
-
-
Field Summary
Fields Modifier and Type Field Description protected booleanifModelExistsprotected org.apache.calcite.sql.SqlIdentifiermodelNamestatic org.apache.calcite.sql.SqlSpecialOperatorOPERATOR
-
Constructor Summary
Constructors Constructor Description SqlAlterModel(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier modelName, boolean ifModelExists)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description String[]fullModelName()org.apache.calcite.sql.SqlIdentifiergetModelName()org.apache.calcite.sql.SqlOperatorgetOperator()booleanifModelExists()Whether to ignore the error if the model doesn't exist.voidunparse(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)-
Methods inherited from class org.apache.calcite.sql.SqlCall
accept, clone, equalsDeep, findValidOptions, getCallSignature, getFunctionQuantifier, getKind, getMonotonicity, getOperandList, isCountStar, isExpanded, operand, operandCount, setOperand, validate
-
-
-
-
Method Detail
-
getOperator
public org.apache.calcite.sql.SqlOperator getOperator()
- Specified by:
getOperatorin classorg.apache.calcite.sql.SqlCall
-
getModelName
public org.apache.calcite.sql.SqlIdentifier getModelName()
-
fullModelName
public String[] fullModelName()
-
ifModelExists
public boolean ifModelExists()
Whether to ignore the error if the model doesn't exist.- Returns:
- true when IF EXISTS is specified.
-
unparse
public void unparse(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)- Overrides:
unparsein classorg.apache.calcite.sql.SqlCall
-
-