Package org.apache.flink.sql.parser.ddl
Class TableSchemaContext
- java.lang.Object
-
- org.apache.flink.sql.parser.ddl.TableSchemaContext
-
- Direct Known Subclasses:
TableSchemaContext.AlterTableSchemaContext
public class TableSchemaContext extends Object
Table schema creation context.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classTableSchemaContext.AlterTableSchemaContextAlter table context.
-
Field Summary
Fields Modifier and Type Field Description List<org.apache.calcite.sql.SqlNode>columnListList<SqlTableConstraint>constraintsSqlWatermarkwatermark
-
Constructor Summary
Constructors Constructor Description TableSchemaContext()
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanisColumnsIdentifiersOnly()
-
-
-
Field Detail
-
columnList
public List<org.apache.calcite.sql.SqlNode> columnList
-
constraints
public List<SqlTableConstraint> constraints
-
watermark
@Nullable public SqlWatermark watermark
-
-