Uses of Class
org.apache.flink.sql.parser.ddl.SqlAlterObject
-
-
Uses of SqlAlterObject in org.apache.flink.sql.parser.ddl
Subclasses of SqlAlterObject in org.apache.flink.sql.parser.ddl Modifier and Type Class Description classSqlAlterDatabaseALTER Database DDL sql call.classSqlAlterFunctionAlter Function Sql Call. -
Uses of SqlAlterObject in org.apache.flink.sql.parser.ddl.catalog
Subclasses of SqlAlterObject in org.apache.flink.sql.parser.ddl.catalog Modifier and Type Class Description classSqlAlterCatalogAbstract class to describe statements like ALTER CATALOG catalog_name.classSqlAlterCatalogCommentALTER CATALOG catalog_name COMMENT 'comment'.classSqlAlterCatalogOptionsALTER CATALOG catalog_name SET (key1=val1, ...).classSqlAlterCatalogResetALTER CATALOG catalog_name RESET (key1, ...). -
Uses of SqlAlterObject in org.apache.flink.sql.parser.ddl.connection
Subclasses of SqlAlterObject in org.apache.flink.sql.parser.ddl.connection Modifier and Type Class Description classSqlAlterConnectionAbstract class to describe statements like ALTER CONNECTION [IF EXISTS] [[catalogName.]classSqlAlterConnectionRenameALTER CONNECTION [IF EXISTS] [[catalogName.] dataBasesName.]connectionName RENAME TO newConnectionName.classSqlAlterConnectionResetALTER CONNECTION [IF EXISTS] [[catalogName.] dataBasesName.]connectionName RESET ( 'key1' [, 'key2']...).classSqlAlterConnectionSetALTER CONNECTION [IF EXISTS] [[catalogName.] dataBasesName.]connectionName SET ( name=value [, name=value]*). -
Uses of SqlAlterObject in org.apache.flink.sql.parser.ddl.materializedtable
Subclasses of SqlAlterObject in org.apache.flink.sql.parser.ddl.materializedtable Modifier and Type Class Description classSqlAlterMaterializedTableAbstract class to describe statements like ALTER MATERIALIZED TABLE [catalogName.]classSqlAlterMaterializedTableAsQuerySqlNode to describe the ALTER TABLE [catalogName.]classSqlAlterMaterializedTableDistributionSqlNode to describe the ALTER MATERIALIZED TABLE [catalogName.]static classSqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableAddDistributionstatic classSqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableModifyDistributionclassSqlAlterMaterializedTableDropDistributionSqlNode to describe the ALTER MATERIALIZED TABLE [catalogName.]classSqlAlterMaterializedTableFreshnessSqlNode to describe ALTER MATERIALIZED TABLE [catalogName.]classSqlAlterMaterializedTableOptionsSqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]classSqlAlterMaterializedTableRefreshSqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]classSqlAlterMaterializedTableRefreshModeSqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]classSqlAlterMaterializedTableResetSqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]classSqlAlterMaterializedTableResumeSqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]classSqlAlterMaterializedTableSchemaAbstract class to describe statements which are used to alter schema for materialized tables.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableAddSchemaExample: DDL like the below for adding column(s)/constraint/watermark.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropColumnSqlNode to describe ALTER MATERIALIZED TABLE materialized_table_name DROP column clause.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropConstraintALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropPrimaryKeyALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropSchemaAbstract class to describe statements which are used to drop schema components while altering schema of materialized tables.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropWatermarkALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableModifySchemaExample: DDL like the below for modifying column(s)/constraint/watermark.classSqlAlterMaterializedTableSuspendSqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.] -
Uses of SqlAlterObject in org.apache.flink.sql.parser.ddl.model
Subclasses of SqlAlterObject in org.apache.flink.sql.parser.ddl.model Modifier and Type Class Description classSqlAlterModelAbstract class to describe statements like ALTER MODEL [IF EXISTS] [[catalogName.]classSqlAlterModelRenameALTER MODEL [IF EXISTS] [[catalogName.] dataBasesName.]modelName RENAME TO newModelName.classSqlAlterModelResetALTER MODEL [IF EXISTS] [[catalogName.] dataBasesName.]modelName RESET ( 'key1' [, 'key2']...).classSqlAlterModelSetALTER MODEL [IF EXISTS] [[catalogName.] dataBasesName.]modelName SET ( name=value [, name=value]*). -
Uses of SqlAlterObject in org.apache.flink.sql.parser.ddl.view
Subclasses of SqlAlterObject in org.apache.flink.sql.parser.ddl.view Modifier and Type Class Description classSqlAlterViewAbstract class to describe ALTER VIEW statements.classSqlAlterViewAsALTER DDL to change a view's query.classSqlAlterViewPropertiesALTER DDL to change properties of a view.classSqlAlterViewRenameALTER DDL to rename a view.
-