Class SqlAlterMaterializedTableDistribution
- java.lang.Object
-
- org.apache.calcite.sql.SqlNode
-
- org.apache.calcite.sql.SqlCall
-
- org.apache.calcite.sql.SqlAlter
-
- org.apache.flink.sql.parser.ddl.SqlAlterObject
-
- org.apache.flink.sql.parser.ddl.materializedtable.SqlAlterMaterializedTable
-
- org.apache.flink.sql.parser.ddl.materializedtable.SqlAlterMaterializedTableDistribution
-
- All Implemented Interfaces:
Cloneable
- Direct Known Subclasses:
SqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableAddDistribution,SqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableModifyDistribution
public abstract class SqlAlterMaterializedTableDistribution extends SqlAlterMaterializedTable
SqlNode to describe the ALTER MATERIALIZED TABLE [catalogName.][dataBasesName.]tableName (ADD|MODIFY) DISTRIBUTION statement.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableAddDistributionstatic classSqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableModifyDistribution
-
Field Summary
Fields Modifier and Type Field Description protected SqlDistributiondistribution-
Fields inherited from class org.apache.flink.sql.parser.ddl.SqlAlterObject
name
-
-
Constructor Summary
Constructors Constructor Description SqlAlterMaterializedTableDistribution(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier tableName, SqlDistribution distribution)
-
Method Summary
All Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description protected abstract StringgetAlterOperation()Optional<SqlDistribution>getDistribution()List<org.apache.calcite.sql.SqlNode>getOperandList()voidunparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)-
Methods inherited from class org.apache.flink.sql.parser.ddl.SqlAlterObject
getFullName, getOperator
-
Methods inherited from class org.apache.calcite.sql.SqlCall
accept, clone, equalsDeep, findValidOptions, getCallSignature, getFunctionQuantifier, getKind, getMonotonicity, isCountStar, isExpanded, operand, operandCount, setOperand, validate
-
-
-
-
Field Detail
-
distribution
protected final SqlDistribution distribution
-
-
Constructor Detail
-
SqlAlterMaterializedTableDistribution
public SqlAlterMaterializedTableDistribution(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier tableName, SqlDistribution distribution)
-
-
Method Detail
-
getAlterOperation
protected abstract String getAlterOperation()
-
getOperandList
public List<org.apache.calcite.sql.SqlNode> getOperandList()
- Specified by:
getOperandListin classorg.apache.calcite.sql.SqlCall
-
unparseAlterOperation
public void unparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)- Overrides:
unparseAlterOperationin classSqlAlterMaterializedTable
-
getDistribution
public Optional<SqlDistribution> getDistribution()
-
-