Class SqlAlterMaterializedTableSchema
- java.lang.Object
-
- org.apache.calcite.sql.SqlNode
-
- org.apache.calcite.sql.SqlCall
-
- org.apache.calcite.sql.SqlAlter
-
- org.apache.flink.sql.parser.ddl.SqlAlterObject
-
- org.apache.flink.sql.parser.ddl.materializedtable.SqlAlterMaterializedTable
-
- org.apache.flink.sql.parser.ddl.materializedtable.SqlAlterMaterializedTableSchema
-
- All Implemented Interfaces:
Cloneable,ExtendedSqlNode
- Direct Known Subclasses:
SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableAddSchema,SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropSchema,SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableModifySchema
public abstract class SqlAlterMaterializedTableSchema extends SqlAlterMaterializedTable implements ExtendedSqlNode
Abstract class to describe statements which are used to alter schema for materialized tables. See examples in javadoc for child classes.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableAddSchemaExample: DDL like the below for adding column(s)/constraint/watermark.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropColumnSqlNode to describe ALTER MATERIALIZED TABLE materialized_table_name DROP column clause.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropConstraintALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropPrimaryKeyALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropSchemaAbstract class to describe statements which are used to drop schema components while altering schema of materialized tables.static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropWatermarkALTER MATERIALIZED TABLE [catalog_name.]static classSqlAlterMaterializedTableSchema.SqlAlterMaterializedTableModifySchemaExample: DDL like the below for modifying column(s)/constraint/watermark.
-
Field Summary
Fields Modifier and Type Field Description protected org.apache.calcite.sql.SqlNodeListcolumnListprotected List<SqlTableConstraint>constraintsprotected SqlWatermarkwatermark-
Fields inherited from class org.apache.flink.sql.parser.ddl.SqlAlterObject
name
-
-
Constructor Summary
Constructors Constructor Description SqlAlterMaterializedTableSchema(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier materializedTableName, org.apache.calcite.sql.SqlNodeList columnList, List<SqlTableConstraint> constraints, SqlWatermark sqlWatermark)
-
Method Summary
All Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description protected abstract StringgetAlterOperation()org.apache.calcite.sql.SqlNodeListgetColumnPositions()List<SqlTableConstraint>getConstraints()Optional<SqlTableConstraint>getFullConstraint()List<org.apache.calcite.sql.SqlNode>getOperandList()Optional<SqlWatermark>getWatermark()voidunparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)voidvalidate()-
Methods inherited from class org.apache.flink.sql.parser.ddl.SqlAlterObject
getFullName, getOperator
-
Methods inherited from class org.apache.calcite.sql.SqlCall
accept, clone, equalsDeep, findValidOptions, getCallSignature, getFunctionQuantifier, getKind, getMonotonicity, isCountStar, isExpanded, operand, operandCount, setOperand, validate
-
-
-
-
Field Detail
-
columnList
protected final org.apache.calcite.sql.SqlNodeList columnList
-
constraints
protected final List<SqlTableConstraint> constraints
-
watermark
@Nullable protected final SqlWatermark watermark
-
-
Constructor Detail
-
SqlAlterMaterializedTableSchema
public SqlAlterMaterializedTableSchema(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier materializedTableName, org.apache.calcite.sql.SqlNodeList columnList, List<SqlTableConstraint> constraints, @Nullable SqlWatermark sqlWatermark)
-
-
Method Detail
-
getOperandList
@Nonnull public List<org.apache.calcite.sql.SqlNode> getOperandList()
- Specified by:
getOperandListin classorg.apache.calcite.sql.SqlCall
-
validate
public void validate() throws SqlValidateException- Specified by:
validatein interfaceExtendedSqlNode- Throws:
SqlValidateException
-
getColumnPositions
public org.apache.calcite.sql.SqlNodeList getColumnPositions()
-
getWatermark
public Optional<SqlWatermark> getWatermark()
-
getConstraints
public List<SqlTableConstraint> getConstraints()
-
getFullConstraint
public Optional<SqlTableConstraint> getFullConstraint()
-
getAlterOperation
protected abstract String getAlterOperation()
-
unparseAlterOperation
public void unparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)- Overrides:
unparseAlterOperationin classSqlAlterMaterializedTable
-
-