Enum SqlStartMode.SqlStartModeKind
- java.lang.Object
-
- java.lang.Enum<SqlStartMode.SqlStartModeKind>
-
- org.apache.flink.sql.parser.ddl.materializedtable.SqlStartMode.SqlStartModeKind
-
- All Implemented Interfaces:
Serializable,Comparable<SqlStartMode.SqlStartModeKind>
- Enclosing class:
- SqlStartMode
public static enum SqlStartMode.SqlStartModeKind extends Enum<SqlStartMode.SqlStartModeKind>
-
-
Enum Constant Summary
Enum Constants Enum Constant Description FROM_BEGINNINGFROM_NOWFROM_TIMESTAMPRESUME_OR_FROM_BEGINNINGRESUME_OR_FROM_NOWRESUME_OR_FROM_TIMESTAMP
-
Method Summary
All Methods Static Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanisCreateOrAlterOption()booleanisFromNow()booleanisFromTimestamp()org.apache.calcite.sql.SqlLiteralsymbol(org.apache.calcite.sql.parser.SqlParserPos pos)Creates a parse-tree node representing an occurrence of this keyword at a particular position in the parsed text.static SqlStartMode.SqlStartModeKindvalueOf(String name)Returns the enum constant of this type with the specified name.static SqlStartMode.SqlStartModeKind[]values()Returns an array containing the constants of this enum type, in the order they are declared.
-
-
-
Enum Constant Detail
-
FROM_BEGINNING
public static final SqlStartMode.SqlStartModeKind FROM_BEGINNING
-
FROM_NOW
public static final SqlStartMode.SqlStartModeKind FROM_NOW
-
FROM_TIMESTAMP
public static final SqlStartMode.SqlStartModeKind FROM_TIMESTAMP
-
RESUME_OR_FROM_BEGINNING
public static final SqlStartMode.SqlStartModeKind RESUME_OR_FROM_BEGINNING
-
RESUME_OR_FROM_NOW
public static final SqlStartMode.SqlStartModeKind RESUME_OR_FROM_NOW
-
RESUME_OR_FROM_TIMESTAMP
public static final SqlStartMode.SqlStartModeKind RESUME_OR_FROM_TIMESTAMP
-
-
Method Detail
-
values
public static SqlStartMode.SqlStartModeKind[] values()
Returns an array containing the constants of this enum type, in the order they are declared. This method may be used to iterate over the constants as follows:for (SqlStartMode.SqlStartModeKind c : SqlStartMode.SqlStartModeKind.values()) System.out.println(c);
- Returns:
- an array containing the constants of this enum type, in the order they are declared
-
valueOf
public static SqlStartMode.SqlStartModeKind valueOf(String name)
Returns the enum constant of this type with the specified name. The string must match exactly an identifier used to declare an enum constant in this type. (Extraneous whitespace characters are not permitted.)- Parameters:
name- the name of the enum constant to be returned.- Returns:
- the enum constant with the specified name
- Throws:
IllegalArgumentException- if this enum type has no constant with the specified nameNullPointerException- if the argument is null
-
symbol
public org.apache.calcite.sql.SqlLiteral symbol(org.apache.calcite.sql.parser.SqlParserPos pos)
Creates a parse-tree node representing an occurrence of this keyword at a particular position in the parsed text.
-
isFromNow
public boolean isFromNow()
-
isFromTimestamp
public boolean isFromTimestamp()
-
isCreateOrAlterOption
public boolean isCreateOrAlterOption()
-
-