| SqlAlterMaterializedTable |
Abstract class to describe statements like ALTER MATERIALIZED TABLE
[catalogName.]
|
| SqlAlterMaterializedTableAsQuery |
SqlNode to describe the ALTER TABLE [catalogName.]
|
| SqlAlterMaterializedTableDistribution |
SqlNode to describe the ALTER MATERIALIZED TABLE [catalogName.]
|
| SqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableAddDistribution |
|
| SqlAlterMaterializedTableDistribution.SqlAlterMaterializedTableModifyDistribution |
|
| SqlAlterMaterializedTableDropDistribution |
SqlNode to describe the ALTER MATERIALIZED TABLE [catalogName.]
|
| SqlAlterMaterializedTableFreshness |
SqlNode to describe ALTER MATERIALIZED TABLE [catalogName.]
|
| SqlAlterMaterializedTableOptions |
SqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableRefresh |
SqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableRefreshMode |
SqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableReset |
SqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableResume |
SqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableSchema |
Abstract class to describe statements which are used to alter schema for materialized tables.
|
| SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableAddSchema |
Example: DDL like the below for adding column(s)/constraint/watermark.
|
| SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropColumn |
SqlNode to describe ALTER MATERIALIZED TABLE materialized_table_name DROP column clause.
|
| SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropConstraint |
ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropPrimaryKey |
ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropSchema |
Abstract class to describe statements which are used to drop schema components while altering
schema of materialized tables.
|
| SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableDropWatermark |
ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlAlterMaterializedTableSchema.SqlAlterMaterializedTableModifySchema |
Example: DDL like the below for modifying column(s)/constraint/watermark.
|
| SqlAlterMaterializedTableSuspend |
SqlNode to describe ALTER MATERIALIZED TABLE [catalog_name.]
|
| SqlCreateMaterializedTable |
CREATE MATERIALIZED TABLE DDL sql call.
|
| SqlCreateOrAlterMaterializedTable |
CREATE [OR ALTER] MATERIALIZED TABLE DDL sql call.
|
| SqlDropMaterializedTable |
DROP MATERIALIZED TABLE DDL sql call.
|
| SqlStartMode |
Start mode configuration for materialized tables.
|