Class SqlAlterModel

    • Field Summary

      Fields 
      Modifier and Type Field Description
      protected boolean ifModelExists  
      • Fields inherited from class org.apache.calcite.sql.SqlNode

        EMPTY_ARRAY, pos
    • Constructor Summary

      Constructors 
      Constructor Description
      SqlAlterModel​(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier modelName, boolean ifModelExists)  
    • Method Summary

      All Methods Instance Methods Concrete Methods 
      Modifier and Type Method Description
      boolean ifModelExists()
      Whether to ignore the error if the model doesn't exist.
      void unparseAlterOperation​(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)  
      • Methods inherited from class org.apache.calcite.sql.SqlAlter

        getScope, setScope, unparse
      • Methods inherited from class org.apache.calcite.sql.SqlCall

        accept, clone, equalsDeep, findValidOptions, getCallSignature, getFunctionQuantifier, getKind, getMonotonicity, getOperandList, isCountStar, isExpanded, operand, operandCount, setOperand, validate
      • Methods inherited from class org.apache.calcite.sql.SqlNode

        clone, clone, cloneArray, equalDeep, equalDeep, equalsDeep, getParserPosition, isA, toList, toList, toSqlString, toSqlString, toSqlString, toString, unparseWithParentheses, validateExpr
    • Field Detail

      • ifModelExists

        protected final boolean ifModelExists
    • Constructor Detail

      • SqlAlterModel

        public SqlAlterModel​(org.apache.calcite.sql.parser.SqlParserPos pos,
                             org.apache.calcite.sql.SqlIdentifier modelName,
                             boolean ifModelExists)
    • Method Detail

      • ifModelExists

        public boolean ifModelExists()
        Whether to ignore the error if the model doesn't exist.
        Returns:
        true when IF EXISTS is specified.
      • unparseAlterOperation

        public void unparseAlterOperation​(org.apache.calcite.sql.SqlWriter writer,
                                          int leftPrec,
                                          int rightPrec)
        Specified by:
        unparseAlterOperation in class org.apache.calcite.sql.SqlAlter