| SqlAddJar |
Add Jar command to add jar into the classloader.
|
| SqlAddPartitions |
ALTER TABLE DDL to add partitions to a table.
|
| SqlAddPartitions.AlterTableAddPartitionContext |
Alter table add partition context.
|
| SqlAlterDatabase |
ALTER Database DDL sql call.
|
| SqlAlterFunction |
Alter Function Sql Call.
|
| SqlAlterObject |
Base class for ALTER DDL sql calls.
|
| SqlCompilePlan |
AST node for COMPILE PLAN 'planfile' [IF NOT EXISTS] FOR [DML].
|
| SqlCreateDatabase |
CREATE Database DDL sql call.
|
| SqlCreateFunction |
CREATE FUNCTION DDL sql call.
|
| SqlCreateObject |
Base class for CREATE DDL sql calls.
|
| SqlDistribution |
Distribution statement in CREATE TABLE DDL, e.g.
|
| SqlDropDatabase |
DROP DATABASE DDL sql call.
|
| SqlDropFunction |
DROP FUNCTION DDL sql call.
|
| SqlDropObject |
Base class for DROP DDL SQL calls.
|
| SqlDropPartitions |
ALTER TABLE DDL to drop partitions of a table.
|
| SqlDropPartitions.AlterTableDropPartitionsContext |
Alter table add partition context.
|
| SqlRemoveJar |
REMOVE JAR sql call to remove jar from the classloader.
|
| SqlReplaceTableAs |
SqlNode to describe the [CREATE OR] REPLACE TABLE AS (RTAS) syntax.
|
| SqlReset |
SQL call for "RESET" and "RESET 'key'".
|
| SqlSet |
SQL call for "SET" and "SET 'key' = 'value'".
|
| SqlStopJob |
The command to stop a flink job.
|
| SqlTableColumn |
Table column of a CREATE TABLE DDL.
|
| SqlTableColumn.SqlComputedColumn |
A column derived from an expression.
|
| SqlTableColumn.SqlMetadataColumn |
A column derived from metadata.
|
| SqlTableColumn.SqlRegularColumn |
A regular, physical column.
|
| SqlTableOption |
Table options of a DDL, a key-value pair with both key and value as string literal.
|
| SqlUseDatabase |
USE [catalog.]database sql call.
|
| SqlUseModules |
USE MODULES sql call.
|
| SqlWatermark |
Watermark statement in CREATE TABLE DDL, e.g.
|
| TableSchemaContext |
Table schema creation context.
|
| TableSchemaContext.AlterTableSchemaContext |
Alter table context.
|