Class SqlAlterTableDistribution
- java.lang.Object
-
- org.apache.calcite.sql.SqlNode
-
- org.apache.calcite.sql.SqlCall
-
- org.apache.calcite.sql.SqlAlter
-
- org.apache.flink.sql.parser.ddl.table.SqlAlterTable
-
- org.apache.flink.sql.parser.ddl.table.SqlAlterTableDistribution
-
- All Implemented Interfaces:
Cloneable
- Direct Known Subclasses:
SqlAlterTableDistribution.SqlAlterTableAddDistribution,SqlAlterTableDistribution.SqlAlterTableModifyDistribution
public abstract class SqlAlterTableDistribution extends SqlAlterTable
SqlNode to describe the ALTER TABLE [catalogName.][dataBasesName.]tableName (ADD|MODIFY) DISTRIBUTION statement.
-
-
Nested Class Summary
Nested Classes Modifier and Type Class Description static classSqlAlterTableDistribution.SqlAlterTableAddDistributionstatic classSqlAlterTableDistribution.SqlAlterTableModifyDistribution
-
Field Summary
-
Fields inherited from class org.apache.flink.sql.parser.ddl.table.SqlAlterTable
ifTableExists, OPERATOR, partitionSpec, tableIdentifier
-
-
Constructor Summary
Constructors Constructor Description SqlAlterTableDistribution(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier tableName, SqlDistribution distribution)
-
Method Summary
All Methods Instance Methods Abstract Methods Concrete Methods Modifier and Type Method Description protected abstract StringgetAlterOperation()SqlDistributiongetDistribution()List<org.apache.calcite.sql.SqlNode>getOperandList()voidunparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)-
Methods inherited from class org.apache.flink.sql.parser.ddl.table.SqlAlterTable
fullTableName, getOperator, getPartitionKVs, getPartitionSpec, getTableName, ifTableExists
-
Methods inherited from class org.apache.calcite.sql.SqlCall
accept, clone, equalsDeep, findValidOptions, getCallSignature, getFunctionQuantifier, getKind, getMonotonicity, isCountStar, isExpanded, operand, operandCount, setOperand, validate
-
-
-
-
Constructor Detail
-
SqlAlterTableDistribution
public SqlAlterTableDistribution(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier tableName, SqlDistribution distribution)
-
-
Method Detail
-
getAlterOperation
protected abstract String getAlterOperation()
-
getDistribution
public SqlDistribution getDistribution()
-
getOperandList
@Nonnull public List<org.apache.calcite.sql.SqlNode> getOperandList()
- Specified by:
getOperandListin classorg.apache.calcite.sql.SqlCall
-
unparseAlterOperation
public void unparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)- Overrides:
unparseAlterOperationin classSqlAlterTable
-
-