| SqlAlterTable |
Abstract class to describe statements like ALTER TABLE [IF EXISTS] [[catalogName.]
|
| SqlAlterTableAdd |
SqlNode to describe ALTER TABLE [IF EXISTS] table_name ADD column/constraint/watermark clause.
|
| SqlAlterTableDistribution |
SqlNode to describe the ALTER TABLE [catalogName.]
|
| SqlAlterTableDistribution.SqlAlterTableAddDistribution |
|
| SqlAlterTableDistribution.SqlAlterTableModifyDistribution |
|
| SqlAlterTableDrop |
SqlNode to describe ALTER TABLE [IF EXISTS ]table_name DROP column/constraint/watermark clause.
|
| SqlAlterTableDrop.SqlAlterTableDropColumn |
SqlNode to describe ALTER TABLE [IF EXISTS ]table_name DROP column clause.
|
| SqlAlterTableDrop.SqlAlterTableDropConstraint |
ALTER TABLE [IF EXISTS ][catalog_name.]
|
| SqlAlterTableDrop.SqlAlterTableDropPrimaryKey |
ALTER TABLE [IF EXISTS ][catalog_name.]
|
| SqlAlterTableDrop.SqlAlterTableDropWatermark |
ALTER TABLE [IF EXISTS ][catalog_name.]
|
| SqlAlterTableDropDistribution |
SqlNode to describe ALTER TABLE [IF EXISTS] table_name DROP DISTRIBUTION clause.
|
| SqlAlterTableModify |
SqlNode to describe ALTER TABLE [IF EXISTS] table_name MODIFY column/constraint/watermark clause.
|
| SqlAlterTableOptions |
ALTER TABLE [IF EXISTS] [[catalogName.] dataBasesName].tableName SET ( name=value [,
name=value]*).
|
| SqlAlterTableRename |
ALTER TABLE [IF EXISTS] [[catalogName.] dataBasesName].tableName RENAME TO [[catalogName.]
|
| SqlAlterTableRenameColumn |
ALTER TABLE [IF EXISTS] [[catalogName.] dataBasesName].tableName RENAME originColumnName TO
newColumnName.
|
| SqlAlterTableReset |
ALTER TABLE [IF EXISTS] [[catalogName.] dataBasesName].tableName RESET ( 'key1' [, 'key2']*).
|
| SqlAlterTableSchema |
Abstract class to describe statements which are used to alter table schema.
|
| SqlAnalyzeTable |
ANALYZE TABLE to compute the statistics for a given table.
|
| SqlCreateTable |
CREATE TABLE DDL sql call.
|
| SqlCreateTableAs |
SqlNode to describe the CREATE TABLE AS syntax.
|
| SqlCreateTableLike |
SqlNode to describe the CREATE TABLE LIKE syntax.
|
| SqlDropTable |
DROP TABLE DDL sql call.
|
| SqlTableLike |
A LIKE clause in a CREATE TABLE statement.
|
| SqlTableLike.SqlTableLikeOption |
|