Uses of Package
org.apache.flink.sql.parser.ddl.table
-
Packages that use org.apache.flink.sql.parser.ddl.table Package Description org.apache.flink.sql.parser.ddl org.apache.flink.sql.parser.ddl.table org.apache.flink.sql.parser.impl -
Classes in org.apache.flink.sql.parser.ddl.table used by org.apache.flink.sql.parser.ddl Class Description SqlAlterTable Abstract class to describe statements like ALTER TABLE [IF EXISTS] [[catalogName.]SqlCreateTable CREATE TABLE DDL sql call. -
Classes in org.apache.flink.sql.parser.ddl.table used by org.apache.flink.sql.parser.ddl.table Class Description SqlAlterTable Abstract class to describe statements like ALTER TABLE [IF EXISTS] [[catalogName.]SqlAlterTableDistribution SqlNode to describe the ALTER TABLE [catalogName.]SqlAlterTableDrop SqlNode to describe ALTER TABLE [IF EXISTS ]table_name DROP column/constraint/watermark clause.SqlAlterTableSchema Abstract class to describe statements which are used to alter table schema.SqlCreateTable CREATE TABLE DDL sql call.SqlTableLike ALIKEclause in aCREATE TABLEstatement.SqlTableLike.FeatureOption A feature of a table descriptor that will be merged into the new table.SqlTableLike.MergingStrategy A strategy that describes how the features of the parent source table should be merged with the features of the newly created table.SqlTableLike.SqlTableLikeOption A pair ofSqlTableLike.MergingStrategyandSqlTableLike.FeatureOption. -
Classes in org.apache.flink.sql.parser.ddl.table used by org.apache.flink.sql.parser.impl Class Description SqlAlterTable Abstract class to describe statements like ALTER TABLE [IF EXISTS] [[catalogName.]SqlTableLike ALIKEclause in aCREATE TABLEstatement.SqlTableLike.SqlTableLikeOption A pair ofSqlTableLike.MergingStrategyandSqlTableLike.FeatureOption.