Uses of Package
org.apache.flink.sql.parser.dml
-
Packages that use org.apache.flink.sql.parser.dml Package Description org.apache.flink.sql.parser.dml org.apache.flink.sql.parser.impl -
Classes in org.apache.flink.sql.parser.dml used by org.apache.flink.sql.parser.dml Class Description RichSqlInsert ASqlInsertthat have some extension functions like partition, overwriteRichSqlInsertKeyword Defines the keywords that can occur immediately after the "INSERT" keyword.SqlInsertConflictBehavior SQL parser enum for conflict resolution behaviors in INSERT INTO statements. -
Classes in org.apache.flink.sql.parser.dml used by org.apache.flink.sql.parser.impl Class Description SqlBeginStatementSet BEGIN STATEMENT SET.SqlEndStatementSet END.SqlTruncateTable SqlNode to describe TRUNCATE TABLE statement.