Package org.apache.flink.sql.parser.dql
Class SqlRichDescribeConnection
- java.lang.Object
-
- org.apache.calcite.sql.SqlNode
-
- org.apache.calcite.sql.SqlCall
-
- org.apache.flink.sql.parser.dql.SqlRichDescribeConnection
-
- All Implemented Interfaces:
Cloneable
public class SqlRichDescribeConnection extends org.apache.calcite.sql.SqlCallDESCRIBE CONNECTION [EXTENDED] [[catalogName.] dataBasesName].sqlIdentifier sql call. Here we add Rich in className to follow the convention ofSqlDescribeTable, which only had it to distinguish from calcite's original SqlDescribeTable, even though calcite does not have SqlDescribeConnection.
-
-
Field Summary
Fields Modifier and Type Field Description protected org.apache.calcite.sql.SqlIdentifierconnectionNameIdentifierstatic org.apache.calcite.sql.SqlSpecialOperatorOPERATOR
-
Constructor Summary
Constructors Constructor Description SqlRichDescribeConnection(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier connectionNameIdentifier, boolean isExtended)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description String[]fullConnectionName()List<org.apache.calcite.sql.SqlNode>getOperandList()org.apache.calcite.sql.SqlOperatorgetOperator()booleanisExtended()voidunparse(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)-
Methods inherited from class org.apache.calcite.sql.SqlCall
accept, clone, equalsDeep, findValidOptions, getCallSignature, getFunctionQuantifier, getKind, getMonotonicity, isCountStar, isExpanded, operand, operandCount, setOperand, validate
-
-
-
-
Method Detail
-
getOperator
public org.apache.calcite.sql.SqlOperator getOperator()
- Specified by:
getOperatorin classorg.apache.calcite.sql.SqlCall
-
getOperandList
public List<org.apache.calcite.sql.SqlNode> getOperandList()
- Specified by:
getOperandListin classorg.apache.calcite.sql.SqlCall
-
isExtended
public boolean isExtended()
-
fullConnectionName
public String[] fullConnectionName()
-
unparse
public void unparse(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)- Overrides:
unparsein classorg.apache.calcite.sql.SqlCall
-
-