Uses of Package
org.apache.flink.sql.parser
-
Classes in org.apache.flink.sql.parser used by org.apache.flink.sql.parser.ddl Class Description ExtendedSqlNode An remark interface which should be inherited by extended sql nodes which are not supported by Calcite core parser. -
Classes in org.apache.flink.sql.parser used by org.apache.flink.sql.parser.ddl.connection Class Description ExtendedSqlNode An remark interface which should be inherited by extended sql nodes which are not supported by Calcite core parser. -
Classes in org.apache.flink.sql.parser used by org.apache.flink.sql.parser.ddl.materializedtable Class Description ExtendedSqlNode An remark interface which should be inherited by extended sql nodes which are not supported by Calcite core parser. -
Classes in org.apache.flink.sql.parser used by org.apache.flink.sql.parser.ddl.model Class Description ExtendedSqlNode An remark interface which should be inherited by extended sql nodes which are not supported by Calcite core parser. -
Classes in org.apache.flink.sql.parser used by org.apache.flink.sql.parser.ddl.table Class Description ExtendedSqlNode An remark interface which should be inherited by extended sql nodes which are not supported by Calcite core parser. -
Classes in org.apache.flink.sql.parser used by org.apache.flink.sql.parser.impl Class Description SqlPartitionSpecProperty Properties of PartitionSpec, a key-value pair with key as component identifier and value as string literal.