Serialized Form
-
Package org.apache.calcite.sql
-
Class org.apache.calcite.sql.SqlCollation extends Object implements Serializable
-
-
Package org.apache.calcite.sql.type
-
Class org.apache.calcite.sql.type.AbstractSqlType extends org.apache.calcite.rel.type.RelDataTypeImpl implements Serializable
-
Serialized Fields
-
isNullable
boolean isNullable
-
typeName
SqlTypeName typeName
-
-
-
Class org.apache.calcite.sql.type.ArraySqlType extends org.apache.calcite.sql.type.AbstractSqlType implements Serializable
-
Serialized Fields
-
elementType
org.apache.calcite.rel.type.RelDataType elementType
-
-
-
Class org.apache.calcite.sql.type.BasicSqlType extends org.apache.calcite.sql.type.AbstractSqlType implements Serializable
-
Serialized Fields
-
collation
org.apache.calcite.sql.SqlCollation collation
-
precision
int precision
-
scale
int scale
-
typeSystem
org.apache.calcite.rel.type.RelDataTypeSystem typeSystem
-
wrappedCharset
org.apache.calcite.util.SerializableCharset wrappedCharset
-
-
-
Class org.apache.calcite.sql.type.IntervalSqlType extends org.apache.calcite.sql.type.AbstractSqlType implements Serializable
-
Serialized Fields
-
intervalQualifier
org.apache.calcite.sql.SqlIntervalQualifier intervalQualifier
-
typeSystem
org.apache.calcite.rel.type.RelDataTypeSystem typeSystem
-
-
-
Class org.apache.calcite.sql.type.MapSqlType extends org.apache.calcite.sql.type.AbstractSqlType implements Serializable
-
Serialized Fields
-
keyType
org.apache.calcite.rel.type.RelDataType keyType
-
valueType
org.apache.calcite.rel.type.RelDataType valueType
-
-
-
Class org.apache.calcite.sql.type.MeasureSqlType extends org.apache.calcite.sql.type.ApplySqlType implements Serializable
-
Class org.apache.calcite.sql.type.MultisetSqlType extends org.apache.calcite.sql.type.AbstractSqlType implements Serializable
-
Serialized Fields
-
elementType
org.apache.calcite.rel.type.RelDataType elementType
-
-
-
Class org.apache.calcite.sql.type.ObjectSqlType extends org.apache.calcite.sql.type.AbstractSqlType implements Serializable
-
Serialized Fields
-
comparability
org.apache.calcite.rel.type.RelDataTypeComparability comparability
-
family
org.apache.calcite.rel.type.RelDataTypeFamily family
-
sqlIdentifier
org.apache.calcite.sql.SqlIdentifier sqlIdentifier
-
-
-
-
Package org.apache.flink.sql.parser.error
-
Class org.apache.flink.sql.parser.error.SqlValidateException extends Exception implements Serializable
-
Serialized Fields
-
errorPosition
org.apache.calcite.sql.parser.SqlParserPos errorPosition
-
message
String message
-
-
-
-
Package org.apache.flink.sql.parser.impl
-
Class org.apache.flink.sql.parser.impl.ParseException extends Exception implements Serializable
-
Serialized Fields
-
currentToken
Token currentToken
This is the last token that has been consumed successfully. If this object has been created due to a parse error, the token followng this token will (therefore) be the first error token. -
eol
String eol
The end of line string for this machine. -
expectedTokenSequences
int[][] expectedTokenSequences
Each entry in this array is an array of integers. Each array of integers represents a sequence of tokens (by their ordinal values) that is expected at this point of the parse. -
specialConstructor
boolean specialConstructor
This variable determines which constructor was used to create this object and thereby affects the semantics of the "getMessage" method (see below). -
tokenImage
String[] tokenImage
This is a reference to the "tokenImage" array of the generated parser within which the parse error occurred. This array is defined in the generated ...Constants interface.
-
-
-
Class org.apache.flink.sql.parser.impl.TokenMgrError extends Error implements Serializable
-
Serialized Fields
-
errorCode
int errorCode
Indicates the reason why the exception is thrown. It will have one of the above 4 values.
-
-
-