Class SqlAlterModel
- java.lang.Object
-
- org.apache.calcite.sql.SqlNode
-
- org.apache.calcite.sql.SqlCall
-
- org.apache.calcite.sql.SqlAlter
-
- org.apache.flink.sql.parser.ddl.SqlAlterObject
-
- org.apache.flink.sql.parser.ddl.model.SqlAlterModel
-
- All Implemented Interfaces:
Cloneable
- Direct Known Subclasses:
SqlAlterModelRename,SqlAlterModelReset,SqlAlterModelSet
public abstract class SqlAlterModel extends SqlAlterObject
Abstract class to describe statements like ALTER MODEL [IF EXISTS] [[catalogName.] dataBasesName.]modelName ...
-
-
Field Summary
Fields Modifier and Type Field Description protected booleanifModelExists-
Fields inherited from class org.apache.flink.sql.parser.ddl.SqlAlterObject
name
-
-
Constructor Summary
Constructors Constructor Description SqlAlterModel(org.apache.calcite.sql.parser.SqlParserPos pos, org.apache.calcite.sql.SqlIdentifier modelName, boolean ifModelExists)
-
Method Summary
All Methods Instance Methods Concrete Methods Modifier and Type Method Description booleanifModelExists()Whether to ignore the error if the model doesn't exist.voidunparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)-
Methods inherited from class org.apache.flink.sql.parser.ddl.SqlAlterObject
getFullName, getOperator
-
Methods inherited from class org.apache.calcite.sql.SqlCall
accept, clone, equalsDeep, findValidOptions, getCallSignature, getFunctionQuantifier, getKind, getMonotonicity, getOperandList, isCountStar, isExpanded, operand, operandCount, setOperand, validate
-
-
-
-
Method Detail
-
ifModelExists
public boolean ifModelExists()
Whether to ignore the error if the model doesn't exist.- Returns:
- true when IF EXISTS is specified.
-
unparseAlterOperation
public void unparseAlterOperation(org.apache.calcite.sql.SqlWriter writer, int leftPrec, int rightPrec)- Specified by:
unparseAlterOperationin classorg.apache.calcite.sql.SqlAlter
-
-